 /***********************************************************************
 *                                                                      *
 * s1C17702.h                                                           *
 * This is symbol definition file for SVT17702.                         *
 * History :  2008/07/15  Start.                                        *
 *                                                                      *
 ************************************************************************/

#ifndef S1C17702_H_
#define S1C17702_H_

/* Base Address of I/O Area */
#define BASE_ADDR 0x4000


/***********************************************
 ****** Bit Field Definition        ************
 ***********************************************/
/* Const Bit Field For Byte Data. */
struct CBbitF {
	unsigned const int b0	: 1;
	unsigned const int b1	: 1;
	unsigned const int b2	: 1;
	unsigned const int b3	: 1;
	unsigned const int b4	: 1;
	unsigned const int b5	: 1;
	unsigned const int b6	: 1;
	unsigned const int b7	: 1;
};

/* Bit Field For Byte Data. */
struct BbitF {
	unsigned int b0	: 1;
	unsigned int b1	: 1;
	unsigned int b2	: 1;
	unsigned int b3	: 1;
	unsigned int b4	: 1;
	unsigned int b5	: 1;
	unsigned int b6	: 1;
	unsigned int b7	: 1;
};

/* Bit Field For Byte Data. b0-b1 is connected. */
struct BbitF0_1 {
	unsigned int b0_b1	: 2;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b0-b2, b4-b6 are connected. */
struct BbitF0_2And4_6 {
	unsigned int b0_b2	: 3;
	unsigned int b3		: 1;
	unsigned int b4_b6	: 3;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b0-b3 is connected. */
struct BbitF0_3 {
	unsigned int b0_b3	: 4;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b0-b3, b7-b4 are connected. */
struct BbitF0_3And4_7 {
	unsigned int b0_b3	: 4;
	unsigned int b4_b7	: 4;
};

/* Bit Field For Byte Data. b1-b3 is connected. */
struct BbitF1_3 {
	unsigned int b0		: 1;
	unsigned int b1_b3	: 3;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b2-b3 is connected. */
struct BbitF2_3 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2_b3	: 2;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b2-b4 is connected. */
struct BbitF2_4 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2_b4	: 3;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b4-b5 is connected. */
struct BbitF4_5 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4_b5	: 2;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
};

/* Bit Field For Byte Data. b4-b6 is connected. */
struct BbitF4_6 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4_b6	: 3;
	unsigned int b7		: 1;
};

/* Bit Field For Word Data. b4-b5, b6-b7 are connected. */
struct BbitF4_5And6_7 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4_b5	: 2;
	unsigned int b6_b7	: 2;
};

/* Const Bit Field For Word Data. */
struct CWbitF {
	unsigned const int b0	: 1;
	unsigned const int b1	: 1;
	unsigned const int b2	: 1;
	unsigned const int b3	: 1;
	unsigned const int b4	: 1;
	unsigned const int b5	: 1;
	unsigned const int b6	: 1;
	unsigned const int b7	: 1;
	unsigned const int b8	: 1;
	unsigned const int b9	: 1;
	unsigned const int b10	: 1;
	unsigned const int b11	: 1;
	unsigned const int b12	: 1;
	unsigned const int b13	: 1;
	unsigned const int b14	: 1;
	unsigned const int b15	: 1;
};

/* Bit Field For Word Data. */
struct WbitF {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8		: 1;
	unsigned int b9		: 1;
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b1 is connected. */
struct WbitF0_1 {
	unsigned int b0_b1	: 2;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8		: 1;
	unsigned int b9		: 1;
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b3 is connected. */
struct WbitF0_3 {
	unsigned int b0_b3	: 4;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8		: 1;
	unsigned int b9		: 1;
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b5,b8-b13 is connected. */
struct WbitF0_5And8_13 {
	unsigned int b0_b5	: 6;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b13	: 6;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b7 is connected. */
struct WbitF0_7 {
	unsigned int b0_b7	: 8;
	unsigned int b8		: 1;
	unsigned int b9		: 1;
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b15 is connected. */
struct WbitF0_15 {
	unsigned int b0_b15	: 16;
};

/* Bit Field For Word Data. b5-b7 is connected. */
struct WbitF5_7 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5_b7	: 3;
	unsigned int b8		: 1;
	unsigned int b9		: 1;	
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b2, b8-b10 are connected. */
struct WbitF0_2And8_10 {
	unsigned int b0_b2	: 3;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b10	: 3;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b0-b2, b8-b9 are connected. */
struct WbitF0_2And8_9 {
	unsigned int b0_b2	: 3;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b9	: 2;
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b8-b9 is connected. */
struct WbitF8_9 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b9	: 2;
	unsigned int b10	: 1;
	unsigned int b11	: 1;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};
	
/* Bit Field For Word Data. b8-b11 is connected. */
struct WbitF8_11 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b11	: 4;
	unsigned int b12	: 1;
	unsigned int b13	: 1;
	unsigned int b14	: 1;
	unsigned int b15	: 1;
};

/* Bit Field For Word Data. b8-b15 is connected. */
struct WbitF8_15 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b15	: 8;
};

/* Bit Field For Word Data. b8-b11,b12-15 are connected. */
struct WbitF8_11AND12_15 {
	unsigned int b0		: 1;
	unsigned int b1		: 1;
	unsigned int b2		: 1;
	unsigned int b3		: 1;
	unsigned int b4		: 1;
	unsigned int b5		: 1;
	unsigned int b6		: 1;
	unsigned int b7		: 1;
	unsigned int b8_b11	: 4;
	unsigned int b12_b15 : 4;
};


/***********************************************
 ****** The Definition of Prescaler ************
 ****** [PSC]                       ************
 ***********************************************/
// Prescaler Controle Register
#define PSC_CTL			*(volatile unsigned char *)(BASE_ADDR + 0x0020)
#define BF_PSC_CTL			(*(volatile struct BbitF *)(BASE_ADDR + 0x0020))
#define PSC_CTL_PRUND		BF_PSC_CTL.b1		// Prescaler run/stop in debug mode
#define PSC_CTL_PRUN		BF_PSC_CTL.b0		// Prescaler run/stop control


/***********************************************
 ****** The Definition of UART      ************
 ****** [UART]                      ************
 ***********************************************/
// UART Ch.0 Status Register
#define UART_ST0			*(volatile unsigned char *)(BASE_ADDR + 0x0100)
#define BF_UART_ST0			(*(volatile struct BbitF *)(BASE_ADDR + 0x0100))
#define UART_ST0_FER		BF_UART_ST0.b6		// Framing error flag
#define UART_ST0_PER		BF_UART_ST0.b5		// Parity error flag
#define UART_ST0_OER		BF_UART_ST0.b4		// Overrun error flag
#define UART_ST0_RD2B		BF_UART_ST0.b3		// Second byte receive flag
#define UART_ST0_TRBS		BF_UART_ST0.b2		// Transmit busy flag
#define UART_ST0_RDRY		BF_UART_ST0.b1		// Receive data ready flag
#define UART_ST0_TDBE		BF_UART_ST0.b0		// Transmit data buffer empty flag

// UART Ch.0 Transmit Data Register
#define UART_TXD0			*(volatile unsigned char *)(BASE_ADDR + 0x0101)
#define UART_TXD0_TXD		UART_TXD0			// Transmit data

// UART Ch.0 Receive Data Register
#define UART_RXD0			*(volatile unsigned char *)(BASE_ADDR + 0x0102)
#define UART_RXD0_RXD		UART_RXD0			// Receive data in the recive data buffer

// UART Ch.0 Mode Register
#define UART_MOD0			*(volatile unsigned char *)(BASE_ADDR + 0x0103)
#define BF_UART_MOD0		(*(volatile struct BbitF *)(BASE_ADDR + 0x0103))
#define UART_MOD0_CHLN		BF_UART_MOD0.b4		// Character length
#define UART_MOD0_PREN		BF_UART_MOD0.b3		// Parity enable
#define UART_MOD0_PMD		BF_UART_MOD0.b2		// Parity mode select
#define UART_MOD0_STPB		BF_UART_MOD0.b1		// Stop bit select
#define UART_MOD0_SSCK		BF_UART_MOD0.b0		// Input clock select

// UART Ch.0 Control Register
#define UART_CTL0			*(volatile unsigned char *)(BASE_ADDR + 0x0104)
#define BF_UART_CTL0		(*(volatile struct BbitF *)(BASE_ADDR + 0x0104))
#define UART_CTL0_REIEN		BF_UART_CTL0.b6		// Receive error int. enable
#define UART_CTL0_RIEN		BF_UART_CTL0.b5		// Receive buffer full int. enable
#define UART_CTL0_TIEN		BF_UART_CTL0.b4		// Transmit buffer empty int. enable
#define UART_CTL0_RBFI		BF_UART_CTL0.b1		// Receive buffer full int. condition
#define UART_CTL0_RXEN		BF_UART_CTL0.b0		// UART enable

// UART Ch.0 Expansion Register
#define UART_EXP0			*(volatile unsigned char *)(BASE_ADDR + 0x0105)
#define BF_UART_EXP0		(*(volatile struct BbitF4_6 *)(BASE_ADDR + 0x0105))
#define UART_EXP0_IRCLK		BF_UART_EXP0.b4_b6	// IrDA receive detection clock select
#define UART_EXP0_IRMD		BF_UART_EXP0.b0		// IrDA mode select

// UART Ch.1 Status Register
#define UART_ST1			*(volatile unsigned char *)(BASE_ADDR + 0x0120)
#define BF_UART_ST1			(*(volatile struct BbitF *)(BASE_ADDR + 0x0120))
#define UART_ST1_FER		BF_UART_ST1.b6		// Framing error flag
#define UART_ST1_PER		BF_UART_ST1.b5		// Parity error flag
#define UART_ST1_OER		BF_UART_ST1.b4		// Overrun error flag
#define UART_ST1_RD2B		BF_UART_ST1.b3		// Second byte receive flag
#define UART_ST1_TRBS		BF_UART_ST1.b2		// Transmit busy flag
#define UART_ST1_RDRY		BF_UART_ST1.b1		// Receive data ready flag
#define UART_ST1_TDBE		BF_UART_ST1.b0		// Transmit data buffer empty flag

// UART Ch.1Transmit Data Register
#define UART_TXD1			*(volatile unsigned char *)(BASE_ADDR + 0x0121)
#define UART_TXD1_TXD		UART_TXD1			// Transmit data

// UART Ch.1Receive Data Register
#define UART_RXD1			*(volatile unsigned char *)(BASE_ADDR + 0x0122)
#define UART_RXD1_RXD		UART_RXD1			// Receive data in the recive data buffer

// UART Ch.1Mode Register
#define UART_MOD1			*(volatile unsigned char *)(BASE_ADDR + 0x0123)
#define BF_UART_MOD1		(*(volatile struct BbitF *)(BASE_ADDR + 0x0123))
#define UART_MOD1_CHLN		BF_UART_MOD1.b4		// Character length
#define UART_MOD1_PREN		BF_UART_MOD1.b3		// Parity enable
#define UART_MOD1_PMD		BF_UART_MOD1.b2		// Parity mode select
#define UART_MOD1_STPB		BF_UART_MOD1.b1		// Stop bit select
#define UART_MOD1_SSCK		BF_UART_MOD1.b0		// Input clock select

// UART Ch.1Control Register
#define UART_CTL1			*(volatile unsigned char *)(BASE_ADDR + 0x0124)
#define BF_UART_CTL1		(*(volatile struct BbitF *)(BASE_ADDR + 0x0124))
#define UART_CTL1_REIEN		BF_UART_CTL1.b6		// Receive error int. enable
#define UART_CTL1_RIEN		BF_UART_CTL1.b5		// Receive buffer full int. enable
#define UART_CTL1_TIEN		BF_UART_CTL1.b4		// Transmit buffer empty int. enable
#define UART_CTL1_RBFI		BF_UART_CTL1.b1		// Receive buffer full int. condition
#define UART_CTL1_RXEN		BF_UART_CTL1.b0		// UART enable

// UART Ch.1Expansion Register
#define UART_EXP1			*(volatile unsigned char *)(BASE_ADDR + 0x0125)
#define BF_UART_EXP1		(*(volatile struct BbitF4_6 *)(BASE_ADDR + 0x0125))
#define UART_EXP1_IRCLK		BF_UART_EXP1.b4_b6	// IrDA receive detection clock select
#define UART_EXP1_IRMD		BF_UART_EXP1.b0		// IrDA mode select


/***********************************************
 ****** The Definition of 8-bit Timer  Ch.0 ****
 ****** [T8F]                               ****
 ***********************************************/
// 8-bit Timer Ch.0 Input Clock Select Register
#define T8F_CLK0			*(volatile unsigned short *)(BASE_ADDR + 0x0200)
#define BF_T8F_CLK0			(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x0200))
#define T8F_CLK0_DF			BF_T8F_CLK0.b0_b3	// Timer input clock select

// 8-bit Timer Ch.0 Reload Data Register
#define T8F_TR0				*(volatile unsigned short *)(BASE_ADDR + 0x0202)
#define BF_T8F_TR0			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0202))
#define T8F_TR0_TR			BF_T8F_TR0.b0_b7	// Timer reload data

// 8-bit Timer Ch.0 Counter Data Register
#define T8F_TC0				*(volatile unsigned short *)(BASE_ADDR + 0x0204)
#define BF_T8F_TC0			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0204))
#define T8F_TC0_TC			BF_T8F_TC0.b0_b7	//Timer counter data

// 8-bit Timer Ch.0 Control Register
#define T8F_CTL0			*(volatile unsigned short *)(BASE_ADDR + 0x0206)
#define BF_T8F_CTL0			(*(volatile struct WbitF8_11 *)(BASE_ADDR + 0x0206))
#define T8F_CTL0_TFMD		BF_T8F_CTL0.b8_b11	// Fine mode setup
#define T8F_CTL0_TRMD		BF_T8F_CTL0.b4		// Count mode select
#define T8F_CTL0_PRESER		BF_T8F_CTL0.b1		// Timer reset
#define T8F_CTL0_PRUN		BF_T8F_CTL0.b0		// Timer run/stop control

// 8-bit Timer Ch.0 Interrupt Control Register
#define T8F_INT0			*(volatile unsigned short *)(BASE_ADDR + 0x0208)
#define BF_T8F_INT0			(*(volatile struct WbitF *)(BASE_ADDR + 0x0208))
#define T8F_INT0_T8IE		BF_T8F_INT0.b8		// Timer interrupt enable
#define T8F_INT0_T8IF		BF_T8F_INT0.b0		// Timer interrupt flag


/***********************************************
 ****** The Definition of 16-bit Timer *********
 ****** [T16]                          *********
 ***********************************************/
// 16-bit Timer Ch.0 Input Clock Select Register
#define T16_CLK0			*(volatile unsigned short *)(BASE_ADDR + 0x0220)
#define BF_T16_CLK0			(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x0220))
#define T16_CLK0_DF			BF_T16_CLK0.b0_b3	// Timer input clock select

// 16-bit Timer Ch.0 Reload Data Register
#define T16_TR0				*(volatile unsigned short *)(BASE_ADDR + 0x0222)
#define T16_TR0_TR			T16_TR0				// 16-bit timer reload data

// 16-bit Timer Ch.0 Counter Data Register
#define T16_TC0				*(volatile unsigned short *)(BASE_ADDR + 0x0224)
#define T16_TC0_TC			T16_TC0				// 16-bit timer counter data

// 16-bit Timer Ch.0 Control Register
#define T16_CTL0			*(volatile unsigned short *)(BASE_ADDR + 0x0226)
#define BF_T16_CTL0			(*(volatile struct WbitF8_9 *)(BASE_ADDR + 0x0226))
#define T16_CTL0_CKACTV		BF_T16_CTL0.b10		// External clock active level select
#define T16_CTL0_CKSL		BF_T16_CTL0.b8_b9	// Input clock and pulse width measurement mode select 
#define T16_CTL0_TRMD		BF_T16_CTL0.b4		// Count mode select
#define T16_CTL0_PRESER		BF_T16_CTL0.b1		// Timer reset
#define T16_CTL0_PRUN		BF_T16_CTL0.b0		// Timer run/stop controle

// 16-bit Timer Ch.0 Interrupt Control Register
#define T16_INT0			*(volatile unsigned short *)(BASE_ADDR + 0x0228)
#define BF_T16_INT0			(*(volatile struct WbitF *)(BASE_ADDR + 0x0228))
#define T16_INT0_T16IE		BF_T16_INT0.b8		// 16-bit timer interrupt enable
#define T16_INT0_T16IF		BF_T16_INT0.b0		// 16-bit timer interrupt flag

// 16-bit Timer Ch.1 Input Clock Select Register
#define T16_CLK1			*(volatile unsigned short *)(BASE_ADDR + 0x0240)
#define BF_T16_CLK1			(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x0240))
#define T16_CLK1_DF			BF_T16_CLK1.b0_b3	// Timer input clock select

// 16-bit Timer Ch.1 Reload Data Register
#define T16_TR1				*(volatile unsigned short *)(BASE_ADDR + 0x0242)
#define T16_TR1_TR			T16_TR1				// 16-bit timer reload data

// 16-bit Timer Ch.1 Counter Data Register
#define T16_TC1				*(volatile unsigned short *)(BASE_ADDR + 0x0244)
#define T16_TC1_TC			T16_TC1				// 16-bit timer counter data

// 16-bit Timer Ch.1 Control Register
#define T16_CTL1			*(volatile unsigned short *)(BASE_ADDR + 0x0246)
#define BF_T16_CTL1			(*(volatile struct WbitF8_9 *)(BASE_ADDR + 0x0246))
#define T16_CTL1_CKACTV		BF_T16_CTL1.b10		// External clock active level select
#define T16_CTL1_CKSL		BF_T16_CTL1.b8_b9	// Input clock and pulse width measurement mode select
#define T16_CTL1_TRMD		BF_T16_CTL1.b4		// Count mode select
#define T16_CTL1_PRESER		BF_T16_CTL1.b1		// Timer reset
#define T16_CTL1_PRUN		BF_T16_CTL1.b0		// Timer run/stop controle

// 16-bit Timer Ch.1 Interrupt Control Register
#define T16_INT1			*(volatile unsigned short *)(BASE_ADDR + 0x0248)
#define BF_T16_INT1			(*(volatile struct WbitF *)(BASE_ADDR + 0x0248))
#define T16_INT1_T16IE		BF_T16_INT1.b8		// 16-bit timer interrupt enable
#define T16_INT1_T16IF		BF_T16_INT1.b0		// 16-bit timer interrupt flag

// 16-bit Timer Ch.2 Input Clock Select Register
#define T16_CLK2			*(volatile unsigned short *)(BASE_ADDR + 0x0260)
#define BF_T16_CLK2			(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x0260))
#define T16_CLK2_DF			BF_T16_CLK2.b0_b3	// Timer input clock select

// 16-bit Timer Ch.2 Reload Data Register
#define T16_TR2				*(volatile unsigned short *)(BASE_ADDR + 0x0262)
#define T16_TR2_TR			T16_TR2				// 16-bit timer reload data

// 16-bit Timer Ch.2 Counter Data Register
#define T16_TC2				*(volatile unsigned short *)(BASE_ADDR + 0x0264)
#define T16_TC2_TC			T16_TC2				// 16-bit timer counter data

// 16-bit Timer Ch.2 Control Register
#define T16_CTL2			*(volatile unsigned short *)(BASE_ADDR + 0x0266)
#define BF_T16_CTL2			(*(volatile struct WbitF8_9 *)(BASE_ADDR + 0x0266))
#define T16_CTL2_CKACTV		BF_T16_CTL2.b10		// External clock active level select
#define T16_CTL2_CKSL		BF_T16_CTL2.b8_b9	// Input clock and pulse width measurement mode select
#define T16_CTL2_TRMD		BF_T16_CTL2.b4		// Count mode select
#define T16_CTL2_PRESER		BF_T16_CTL2.b1		// Timer reset
#define T16_CTL2_PRUN		BF_T16_CTL2.b0		// Timer run/stop controle

// 16-bit Timer Ch.2 Interrupt Control Register
#define T16_INT2			*(volatile unsigned short *)(BASE_ADDR + 0x0268)
#define BF_T16_INT2			(*(volatile struct WbitF *)(BASE_ADDR + 0x0268))
#define T16_INT2_T16IE		BF_T16_INT2.b8		// 16-bit timer interrupt enable
#define T16_INT2_T16IF		BF_T16_INT2.b0		// 16-bit timer interrupt flag


/***********************************************
 ****** The Definition of 8-bit Timer  Ch.1 ****
 ****** [T8F]                               ****
 ***********************************************/
// 8-bit Timer Ch.1 Input Clock Select Register
#define T8F_CLK1			*(volatile unsigned short *)(BASE_ADDR + 0x0280)
#define BF_T8F_CLK1			(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x0280))
#define T8F_CLK1_DF			BF_T8F_CLK1.b0_b3	// Timer input clock select

// 8-bit Timer Ch.1 Reload Data Register
#define T8F_TR1				*(volatile unsigned short *)(BASE_ADDR + 0x0282)
#define BF_T8F_TR1			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0282))
#define T8F_TR1_TR			BF_T8F_TR1.b0_b7	// Timer reload data

// 8-bit Timer Ch.1 Counter Data Register
#define T8F_TC1				*(volatile unsigned short *)(BASE_ADDR + 0x0284)
#define BF_T8F_TC1			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0284))
#define T8F_TC1_TC			BF_T8F_TC1.b0_b7	//Timer counter data

// 8-bit Timer Ch.1 Control Register
#define T8F_CTL1			*(volatile unsigned short *)(BASE_ADDR + 0x0286)
#define BF_T8F_CTL1			(*(volatile struct WbitF8_11 *)(BASE_ADDR + 0x0286))
#define T8F_CTL1_TFMD		BF_T8F_CTL1.b8_b11	// Fine mode setup
#define T8F_CTL1_TRMD		BF_T8F_CTL1.b4		// Count mode select
#define T8F_CTL1_PRESER		BF_T8F_CTL1.b1		// Timer reset
#define T8F_CTL1_PRUN		BF_T8F_CTL1.b0		// Timer run/stop control

// 8-bit Timer Ch.1 Interrupt Control Register
#define T8F_INT1			*(volatile unsigned short *)(BASE_ADDR + 0x0288)
#define BF_T8F_INT1			(*(volatile struct WbitF *)(BASE_ADDR + 0x0288))
#define T8F_INT1_T8IE		BF_T8F_INT1.b8		// Timer interrupt enable
#define T8F_INT1_T8IF		BF_T8F_INT1.b0		// Timer interrupt flag


/***********************************************
 ****** The Definition of Interrupt Controller *
 ****** [ITC]                                  *
 ***********************************************/
// External Interrupt Level Setup Register 0
#define ITC_LV0				*(volatile unsigned short *)(BASE_ADDR + 0x0306)
#define BF_ITC_LV0			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x0306))
#define ITC_LV0_ILV1		BF_ITC_LV0.b8_b10	// P1 interrupt level
#define ITC_LV0_ILV0		BF_ITC_LV0.b0_b2	// P0 interrupt level

// External Interrupt Level Setup Register 1
#define ITC_LV1				*(volatile unsigned short *)(BASE_ADDR + 0x0308)
#define BF_ITC_LV1			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x0308))
#define ITC_LV1_ILV3		BF_ITC_LV1.b8_b10	// CT interrupt level
#define ITC_LV1_ILV2		BF_ITC_LV1.b0_b2	// SWT interrupt level

// External Interrupt Level Setup Register 2
#define ITC_LV2				*(volatile unsigned short *)(BASE_ADDR + 0x030a)
#define BF_ITC_LV2			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x030a))
#define ITC_LV2_ILV5		BF_ITC_LV2.b8_b10	// SVD interrupt level
#define ITC_LV2_ILV4		BF_ITC_LV2.b0_b2	// T8OSC1 interrupt level

// External Interrupt Level Setup Register 3
#define ITC_LV3				*(volatile unsigned short *)(BASE_ADDR + 0x030c)
#define BF_ITC_LV3			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x030c))
#define ITC_LV3_ILV7		BF_ITC_LV3.b8_b10	// T16E Ch.0 interrupt level
#define ITC_LV3_ILV6		BF_ITC_LV3.b0_b2	// LCD interrupt level

// Internal Interrupt Level Setup Register 4
#define ITC_LV4				*(volatile unsigned short *)(BASE_ADDR + 0x030e)
#define BF_ITC_LV4			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x030e))
#define ITC_LV4_ILV9		BF_ITC_LV4.b8_b10	// T16 Ch.0 interrupt level
#define ITC_LV4_ILV8		BF_ITC_LV4.b0_b2	// T8 interrupt level

// Internal Interrupt Level Setup Register 5
#define ITC_LV5				*(volatile unsigned short *)(BASE_ADDR + 0x0310)
#define BF_ITC_LV5			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x0310))
#define ITC_LV5_ILV11		BF_ITC_LV5.b8_b10	// T16 Ch.2 interrupt level
#define ITC_LV5_ILV10		BF_ITC_LV5.b0_b2	// T16 Ch.1 interrupt level

// Internal Interrupt Level Setup Register 6
#define ITC_LV6				*(volatile unsigned short *)(BASE_ADDR + 0x0312)
#define BF_ITC_LV6			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x0312))
#define ITC_LV6_ILV13		BF_ITC_LV6.b8_b10	// UART Ch.1 interrupt level
#define ITC_LV6_ILV12		BF_ITC_LV6.b0_b2	// UART Ch.0 interrupt level

// Internal Interrupt Level Setup Register 7
#define ITC_LV7				*(volatile unsigned short *)(BASE_ADDR + 0x0314)
#define BF_ITC_LV7			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x0314))
#define ITC_LV7_ILV15		BF_ITC_LV7.b8_b10	// I2C interrupt level
#define ITC_LV7_ILV14		BF_ITC_LV7.b0_b2	// SPI interrupt level

// Internal Interrupt Level Setup Register 8
#define ITC_LV8				*(volatile unsigned short *)(BASE_ADDR + 0x0316)
#define BF_ITC_LV8			(*(volatile struct WbitF0_2And8_10 *)(BASE_ADDR + 0x0316))
#define ITC_LV8_ILV17		BF_ITC_LV8.b8_b10	// T16E Ch.1 interrupt level
#define ITC_LV8_ILV16		BF_ITC_LV8.b0_b2	// REMC interrupt level


/***********************************************
 ****** The Definition of SPI ******************
 ****** [SPI]                 ******************
 ***********************************************/
// SPI Status Register
#define SPI_ST				*(volatile unsigned short *)(BASE_ADDR + 0x0320)
#define BF_SPI_ST			(*(volatile struct WbitF *)(BASE_ADDR + 0x0320))
#define SPI_ST_SPBSY		BF_SPI_ST.b2		// Transfer busy flag(master) / ss signal low flag(slave)
#define SPI_ST_SPRBF		BF_SPI_ST.b1		// Receive data buffer full flag
#define SPI_ST_SPTBE		BF_SPI_ST.b0		// Transmit data buffer empty flag

// SPI Transmit Data Register
#define SPI_TXD				*(volatile unsigned short *)(BASE_ADDR + 0x0322)
#define BF_SPI_TXD			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0322))
#define SPI_TXD_SPTDB		BF_SPI_TXD.b0_b7	// SPI transmit data buffer

// SPI Receive Data Register
#define SPI_RXD				*(volatile unsigned short *)(BASE_ADDR + 0x0324)
#define BF_SPI_RXD			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0324))
#define SPI_RXD_SPRDB		BF_SPI_RXD.b0_b7	// SPI receive data buffer

// SPI Control Register
#define SPI_CTL				*(volatile unsigned short *)(BASE_ADDR + 0x0326)
#define BF_SPI_CTL			(*(volatile struct WbitF *)(BASE_ADDR + 0x0326))
#define SPI_CTL_MCLK		BF_SPI_CTL.b9		// SPI clock source select
#define SPI_CTL_MLSB		BF_SPI_CTL.b8		// LSB/MSB first mode select
#define SPI_CTL_SPRIE		BF_SPI_CTL.b5		// Receive data buffer full int. enable
#define SPI_CTL_SPTIE		BF_SPI_CTL.b4		// Transmit data buffer empty int. enable
#define SPI_CTL_CPHA		BF_SPI_CTL.b3		// Clock phase select
#define SPI_CTL_CPOL		BF_SPI_CTL.b2		// Clock polarity select
#define SPI_CTL_MSSL		BF_SPI_CTL.b1		// Master/slave mode select
#define SPI_CTL_SPEN		BF_SPI_CTL.b0		// SPI enable


/***********************************************
 ****** The Definition of I2C ******************
 ****** [I2C]                 ******************
 ***********************************************/
// I2C Enable Register
#define I2C_EN				*(volatile unsigned short *)(BASE_ADDR + 0x0340)
#define BF_I2C_EN			(*(volatile struct WbitF *)(BASE_ADDR + 0x0340))
#define I2C_EN_I2CEN		BF_I2C_EN.b0		// I2C enable

// I2C Control Tegister
#define I2C_CTL				*(volatile unsigned short *)(BASE_ADDR + 0x0342)
#define BF_I2C_CTL			(*(volatile struct WbitF *)(BASE_ADDR + 0x0342))
#define I2C_CTL_RBUSY		BF_I2C_CTL.b9		// Receive busy flag
#define I2C_CTL_TBUSY		BF_I2C_CTL.b8		// Transmit busy flag
#define I2C_CTL_CSTR		BF_I2C_CTL.b5		// Clock stretch on/off
#define I2C_CTL_NSERM		BF_I2C_CTL.b4		// Noise remove on/off
#define I2C_CTL_STP			BF_I2C_CTL.b1		// Stop control
#define I2C_CTL_STRT		BF_I2C_CTL.b0		// Start control

// I2C Data Register
#define I2C_DAT				*(volatile unsigned short *)(BASE_ADDR + 0x0344)
#define BF_I2C_DAT			(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x0344))
#define I2C_DAT_RBRDY		BF_I2C_DAT.b11		// Receive buffer ready
#define I2C_DAT_RXE			BF_I2C_DAT.b10		// Recive execution
#define I2C_DAT_TXE			BF_I2C_DAT.b9		// Transmit execution
#define I2C_DAT_RTACK		BF_I2C_DAT.b8		// Receive/transmit ACK
#define I2C_DAT_RTDT		BF_I2C_DAT.b0_b7	// Receive/transmit data

// I2C Interrupt Control Register
#define I2C_ICTL			*(volatile unsigned short *)(BASE_ADDR + 0x0346)
#define BF_I2C_ICTL			(*(volatile struct WbitF *)(BASE_ADDR + 0x0346))
#define I2C_ICTL_RINTE		BF_I2C_ICTL.b1		// Receive interrupt enable
#define I2C_ICTL_TINTE		BF_I2C_ICTL.b0		// Transmit interrupt eneble


/***********************************************
 ****** The Definition of ClockTimer ***********
 ****** [CT]                         ***********
 ***********************************************/
// ClockTimer Control Register
#define CT_CTL				*(volatile unsigned char *)(BASE_ADDR + 0x1000)
#define BF_CT_CTL			(*(volatile struct BbitF *)(BASE_ADDR + 0x1000))
#define CT_CTL_CTRST		BF_CT_CTL.b4		// Clock timer reset
#define CT_CTL_CTRUN		BF_CT_CTL.b0		// Clock timer run/stop control

// Clock Timer Counter Register
#define CT_CNT				*(volatile unsigned char *)(BASE_ADDR + 0x1001)
#define CT_CNT_CTCNT		CT_CNT				// Clock timer counter value

// Clock Timer Interrupt Mask Register
#define CT_IMSK				*(volatile unsigned char *)(BASE_ADDR + 0x1002)
#define BF_CT_IMSK			(*(volatile struct BbitF *)(BASE_ADDR + 0x1002))
#define CT_IMSK_CTIE32		BF_CT_IMSK.b3		// 32 Hz interrupt enable
#define CT_IMSK_CTIE8		BF_CT_IMSK.b2		// 8 Hz interrupt enable
#define CT_IMSK_CTIE2		BF_CT_IMSK.b1		// 2 Hz interrupt enable
#define CT_IMSK_CTIE1		BF_CT_IMSK.b0		// 1 Hz interrupt enable

// Clock Timer Interrupt Flag Register
#define CT_IFLG				*(volatile unsigned char *)(BASE_ADDR + 0x1003)
#define BF_CT_IFLG			(*(volatile struct CBbitF *)(BASE_ADDR + 0x1003))
#define CT_IFLG_CTIF32		BF_CT_IFLG.b3		// 32 Hz interrupt flag  (read only)
#define CT_IFLG_CTIF8		BF_CT_IFLG.b2		// 8 Hz interrupt flag  (read only)
#define CT_IFLG_CTIF2		BF_CT_IFLG.b1		// 2 Hz interrupt flag  (read only)
#define CT_IFLG_CTIF1		BF_CT_IFLG.b0		// 1 Hz interrupt flag  (read only)


/***********************************************
 ****** The Definition of Stopwatch Timer ******
 ****** [SWT]                             ******
 ***********************************************/
// Stopwatch Timer Control Register
#define SWT_CTL				*(volatile unsigned char *)(BASE_ADDR + 0x1020)
#define BF_SWT_CTL			(*(volatile struct BbitF *)(BASE_ADDR + 0x1020))
#define SWT_CTL_SWTRST		BF_SWT_CTL.b4		// Stopwatch timer reset
#define SWT_CTL_SWTRUN		BF_SWT_CTL.b0		// Stopwatch timer run/stop control

// Stopwatch Timer BCD Counter Register
#define SWT_BCNT			*(volatile unsigned char *)(BASE_ADDR + 0x1021)
#define BF_SWT_BCNT			(*(volatile struct BbitF0_3And4_7 *)(BASE_ADDR + 0x1021))
#define SWT_BCNT_BCD10		BF_SWT_BCNT.b4_b7	// 1/10 sec. BCD counter value
#define SWT_BCNT_BCD100		BF_SWT_BCNT.b0_b3	// 1/100 sec. BCD counter value

// Stopwatch Timer Interruput Mask Register
#define SWT_IMSK			*(volatile unsigned char *)(BASE_ADDR + 0x1022)
#define BF_SWT_IMSK			(*(volatile struct BbitF *)(BASE_ADDR + 0x1022))
#define SWT_IMSK_SIE1		BF_SWT_IMSK.b2		// 1 Hz interrupt enable
#define SWT_IMSK_SIE10		BF_SWT_IMSK.b1		// 10 Hz interrupt enable
#define SWT_IMSK_SIE100		BF_SWT_IMSK.b0		// 100 Hz interrupt enable

// Stopwatch Timer Interrupt Flag Register
#define SWT_IFLG			*(volatile unsigned char *)(BASE_ADDR + 0x1023)
#define BF_SWT_IFLG			(*(volatile struct CBbitF *)(BASE_ADDR + 0x1023))
#define SWT_IFLG_SIF1		BF_SWT_IFLG.b2		// 1 Hz interrupt flag  (read only)
#define SWT_IFLG_SIF10		BF_SWT_IFLG.b1		// 10 Hz interrupt flag  (read only)
#define SWT_IFLG_SIF100		BF_SWT_IFLG.b0		// 100 Hz interrupt flag  (read only)


/***********************************************
 ****** The Definition of Watchdog Timer *******
 ****** [WDT]                            *******
 ***********************************************/
// Watchdog TImer Controle Register
#define WDT_CTL				*(volatile unsigned char *)(BASE_ADDR + 0x1040)
#define BF_WDT_CTL			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1040))
#define WDT_CTL_WDTRST		BF_WDT_CTL.b4		// Watchdog timer reset
#define WDT_CTL_WDTRUN		BF_WDT_CTL.b0_b3	// Watchdog timer run/stop control

// Watchdog Timer Status Register
#define WDT_ST				*(volatile unsigned char *)(BASE_ADDR + 0x1041)
#define BF_WDT_ST			(*(volatile struct BbitF *)(BASE_ADDR + 0x1041))
#define WDT_ST_WDTMD		BF_WDT_ST.b1		// NMI/Reset mode select
#define WDT_ST_WDTST		BF_WDT_ST.b0		// NMI status


/***********************************************
 ****** The Definition of Oscillator ***********
 ****** [OSC]                        ***********
 ***********************************************/
// Clock Souce Slect Register
#define OSC_SRC				*(volatile unsigned char *)(BASE_ADDR + 0x1060)
#define BF_OSC_SRC			(*(volatile struct BbitF *)(BASE_ADDR + 0x1060))
#define OSC_SRC_HSCLKSEL	BF_OSC_SRC.b1		// High-speed clock select
#define OSC_SRC_CLKSRC		BF_OSC_SRC.b0		// System clock source select

// Oscillation Controle Register
#define OSC_CTL				*(volatile unsigned char *)(BASE_ADDR + 0x1061)
#define BF_OSC_CTL			(*(volatile struct BbitF4_5And6_7 *)(BASE_ADDR + 0x1061))
#define OSC_CTL_IOSCWT		BF_OSC_CTL.b6_b7	// IOSC wait cycle select
#define OSC_CTL_OSC3WT		BF_OSC_CTL.b4_b5	// OSC3 wait cycle select
#define OSC_CTL_IOSCEN		BF_OSC_CTL.b2		// IOSC enable
#define OSC_CTL_OSC1EN		BF_OSC_CTL.b1		// OSC1 enable
#define OSC_CTL_OSC3EN		BF_OSC_CTL.b0		// OSE3 enable

// Noise Filter Enable Register
#define OSC_NFEN			*(volatile unsigned char *)(BASE_ADDR + 0x1062)
#define BF_OSC_NFEN			(*(volatile struct BbitF *)(BASE_ADDR + 0x1062))
#define OSC_NFEN_DSINFE		BF_OSC_NFEN.b4		// DSIN noise filter enable
#define OSC_NFEN_RSTFE		BF_OSC_NFEN.b1		// Reset noise filter enalbe
#define OSC_NFEN_NMIFE		BF_OSC_NFEN.b0		// NMI noise filter enable

// LCD Clock Setup Register
#define OSC_LCLK			*(volatile unsigned char *)(BASE_ADDR + 0x1063)
#define BF_OSC_LCLK			(*(volatile struct BbitF2_4 *)(BASE_ADDR + 0x1063))
#define OSC_LCLK_LCKDV		BF_OSC_LCLK.b2_b4	// LCD clock division ratio select
#define OSC_LCLK_LCKSRC		BF_OSC_LCLK.b1		// LCD clock source select
#define OSC_LCLK_LCKEN		BF_OSC_LCLK.b0		// LCD clock enable

// FOUT Control Register
#define OSC_FOUT			*(volatile unsigned char *)(BASE_ADDR + 0x1064)
#define BF_OSC_FOUT			(*(volatile struct BbitF2_3 *)(BASE_ADDR + 0x1064))
#define OSC_FOUT_FOUTHD		BF_OSC_FOUT.b2_b3	// HSCLK clock division ratio select
#define OSC_FOUT_FOUTHE		BF_OSC_FOUT.b1		// HSCLK output enable
#define OSC_FOUT_FOUT1E		BF_OSC_FOUT.b0		// FOUT1 output enable

// T8OSC1 Clock Control Register
#define OSC_T8OSC1			*(volatile unsigned char *)(BASE_ADDR + 0x1065)
#define BF_OSC_T8OSC1		(*(volatile struct BbitF1_3 *)(BASE_ADDR + 0x1065))
#define OSC_T8OSC1_T8O1CK	BF_OSC_T8OSC1.b1_b3	// T8OSC1 clock division ratio select
#define OSC_T8OSC1_T8O1CE	BF_OSC_T8OSC1.b0	// T8OSC1 clock output enable


/***********************************************
 ****** The Definition of Clock Generator ******
 ****** [CLG]                             ******
 ***********************************************/
// PCLK Control Register
#define CLG_PCLK			*(volatile unsigned char *)(BASE_ADDR + 0x1080)
#define BF_CLG_PCLK			(*(volatile struct BbitF0_1 *)(BASE_ADDR + 0x1080))
#define CLG_PCLK_PCKEN		BF_CLG_PCLK.b0_b1	// PCLK enable

// CCLK Control Register
#define CLG_CCLK			*(volatile unsigned char *)(BASE_ADDR + 0x1081)
#define BF_CLG_CCLK			(*(volatile struct BbitF0_1 *)(BASE_ADDR + 0x1081))
#define CLG_CCLK_CCLKGR		BF_CLG_CCLK.b0_b1	// CCLK clock gear ratio select


/***********************************************
 ****** The Definition of LCD Driver ***********
 ****** [LCD]                        ***********
 ***********************************************/
// LCD Display Control Register
#define LCD_DCTL			*(volatile unsigned char *)(BASE_ADDR + 0x10a0)
#define BF_LCD_DCTL			(*(volatile struct BbitF0_1 *)(BASE_ADDR + 0x10a0))
#define LCD_DCTL_SEGREV		BF_LCD_DCTL.b7		// Segment output assignment control
#define LCD_DCTL_COMREV		BF_LCD_DCTL.b6		// Common output assignment control
#define LCD_DCTL_DSPAR		BF_LCD_DCTL.b5		// Display memory area control
#define LCD_DCTL_DSPREV		BF_LCD_DCTL.b4		// Reverse display control
#define LCD_DCTL_DSPC		BF_LCD_DCTL.b0_b1	// LDC display control

// LCD Contrast Adjust Register
#define LCD_CADJ			*(volatile unsigned char *)(BASE_ADDR + 0x10a1)
#define BF_LCD_CADJ			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x10a1))
#define LCD_CADJ_LC			BF_LCD_CADJ.b0_b3	// LCD contrast adjustment

// LCD Clock Control Register
#define LCD_CCTL			*(volatile unsigned char *)(BASE_ADDR + 0x10a2)
#define BF_LCD_CCTL			(*(volatile struct BbitF0_1 *)(BASE_ADDR + 0x10a2))
#define LCD_CCTL_LFROUT		BF_LCD_CCTL.b5		// Frame signal output control
#define LCD_CCTL_LCKOUT		BF_LCD_CCTL.b4		// LCD clock output control
#define LCD_CCTL_LDUTY		BF_LCD_CCTL.b0_b1	// LCD duty select

// LCD Voltage Regulator Control Register
#define LCD_VREG			*(volatile unsigned char *)(BASE_ADDR + 0x10a3)
#define BF_LCD_VREG			(*(volatile struct BbitF *)(BASE_ADDR + 0x10a3))
#define LCD_VREG_LHVLD		BF_LCD_VREG.b4		// LCD heavy load protection mode

// LCD Power Voltage Booster Control Register
#define LCD_PWR				*(volatile unsigned char *)(BASE_ADDR + 0x10a4)
#define BF_LCD_PWR			(*(volatile struct BbitF *)(BASE_ADDR + 0x10a4))
#define LCD_PWR_VDSEL		BF_LCD_PWR.b1		// Regulator power source select
#define LCD_PWR_PBON		BF_LCD_PWR.b0		// Power voltage booster control

// LCD Interrupt Mask Register
#define LCD_IMSK			*(volatile unsigned char *)(BASE_ADDR + 0x10a5)
#define BF_LCD_IMSK			(*(volatile struct BbitF *)(BASE_ADDR + 0x10a5))
#define LCD_IMSK_FRMIE		BF_LCD_IMSK.b0		// Frame signal interrupt enable

// LCD Interrupt Flag Register
#define LCD_IFLG			*(volatile unsigned char *)(BASE_ADDR + 0x10a6)
#define BF_LCD_IFLG			(*(volatile struct CBbitF *)(BASE_ADDR + 0x10a6))
#define LCD_IFLG_FRMIF		BF_LCD_IFLG.b0		// Frame signal interrupt flag  (read only)


/***********************************************
 ****** The Definition of 8-bit OSC1 Timer *****
 ****** [T8OSC1]                           *****
 ***********************************************/
// 8-bit OSC1 Timer Control Register
#define T8OSC1_CTL			*(volatile unsigned char *)(BASE_ADDR + 0x10c0)
#define BF_T8OSC1_CTL		(*(volatile struct BbitF *)(BASE_ADDR + 0x10c0))
#define T8OSC1_CTL_T8ORST	BF_T8OSC1_CTL.b4	// Timer reset
#define T8OSC1_CTL_T8ORMD	BF_T8OSC1_CTL.b1	// Count mode select
#define T8OSC1_CTL_T8ORUN	BF_T8OSC1_CTL.b0	// Timer run/stop control

// 8-bit OSC1 Timer Counter Data Register
#define T8OSC1_CNT			*(volatile unsigned char *)(BASE_ADDR + 0x10c1)
#define T8OSC1_CNT_T8OCNT	T8OSC1_CNT			// Timer counter data

// 8-bit OSC1 Timer Compare Data Register
#define T8OSC1_CMP			*(volatile unsigned char *)(BASE_ADDR + 0x10c2)
#define T8OSC1_CMP_T8OCMP	T8OSC1_CMP			// Compare data

// 8-bit OSC1 Timer Interrupt Mask Register
#define T8OSC1_IMSK			*(volatile unsigned char *)(BASE_ADDR + 0x10c3)
#define BF_T8OSC1_IMSK		(*(volatile struct BbitF *)(BASE_ADDR + 0x10c3))
#define T8OSC1_IMSK_T8OIE	BF_T8OSC1_IMSK.b0	// 8-bit OSC1 timer interrupt enable

// 8-bit OSC1 Timer Interrupt Flag Register
#define T8OSC1_IFLG			*(volatile unsigned char *)(BASE_ADDR + 0x10c4)
#define BF_T8OSC1_IFLG		(*(volatile struct CBbitF *)(BASE_ADDR + 0x10c4))
#define T8OSC1_IFLG_T8OIF	BF_T8OSC1_IFLG.b0	// 8-bit OSC1 timer interrupt flag

// 8-bit OSC1 Timer PWM Output Duty Data
#define T8OSC1_DUTY			*(volatile unsigned char *)(BASE_ADDR + 0x10c5)
#define T8OSC1_DUTY_T8ODTY	T8OSC1_DUTY			// 8-bit OSC1 PWM output duty data


/***********************************************
 ****** The Definition of SVD Circuit **********
 ****** [SVD]                         **********
 ***********************************************/
// SVD Enable Register
#define SVD_EN				*(volatile unsigned char *)(BASE_ADDR + 0x1100)
#define BF_SVD_EN			(*(volatile struct BbitF *)(BASE_ADDR + 0x1100))
#define SVD_EN_SVDEN		BF_SVD_EN.b0		//SVD enable

// SVD Compare Voltage Register
#define SVD_CMP				*(volatile unsigned char *)(BASE_ADDR + 0x1101)
#define BF_SVD_CMP			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1101))
#define SVD_CMP_SVDC		BF_SVD_CMP.b0_b3	// SVD compare voltage

// SVD Detection Result Register
#define SVD_RSLT			*(volatile unsigned char *)(BASE_ADDR + 0x1102)
#define BF_SVD_RSLT			(*(volatile struct BbitF *)(BASE_ADDR + 0x1102))
#define SVD_RSLT_SVDDT		BF_SVD_RSLT.b0		// SVD detection result

// SVD Interrupt Mask Register
#define SVD_IMSK			*(volatile unsigned char *)(BASE_ADDR + 0x1103)
#define BF_SVD_IMSK			(*(volatile struct BbitF *)(BASE_ADDR + 0x1103))
#define SVD_IMSK_SVDIE		BF_SVD_IMSK.b0		// SVD interrupt enable

// SVD Interrupt Flag Register
#define SVD_IFLG			*(volatile unsigned char *)(BASE_ADDR + 0x1104)
#define BF_SVD_IFLG			(*(volatile struct CBbitF *)(BASE_ADDR + 0x1104))
#define SVD_IFLG_SVDIF		BF_SVD_IFLG.b0		// SVD interrupt flag  (read only)


/***********************************************
 ****** The Definition of Power Generator ******
 ****** [VD1]                         **********
 ***********************************************/
// VD1 Control Register
#define VD1_CTL				*(volatile unsigned char *)(BASE_ADDR + 0x1120)
#define BF_VD1_CTL			(*(volatile struct BbitF *)(BASE_ADDR + 0x1120))
#define VD1_CTL_HVLD		BF_VD1_CTL.b4		// VD1 heavy load protection mode
#define VD1_CTL_VD1MD		BF_VD1_CTL.b0		// Flash erase/program mode


/***********************************************
 ****** The Definition of P Port & Port MUX ****
 ****** [Px]                                ****
 ***********************************************/
// P0 Port Input Data Register
#define P0_IN				*(volatile unsigned char *)(BASE_ADDR + 0x1200)
#define P0_IN_P0IN			P0_IN				// P0[7:0] port input data

// P0 Port Output Data Register
#define P0_OUT				*(volatile unsigned char *)(BASE_ADDR + 0x1201)
#define P0_OUT_P0OUT		P0_OUT				// P0[7:0] port output data

// P0 Port I/O Direction Control Register
#define P0_IO				*(volatile unsigned char *)(BASE_ADDR + 0x1202)
#define P0_IO_P0IO			P0_IO				// P0[7:0] port I/O direction select

// P0 Port Pull-up Control Register
#define P0_PU				*(volatile unsigned char *)(BASE_ADDR + 0x1203)
#define P0_PU_P0PU			P0_PU				// P0[7:0] port pull-up enable

// P0 Port Schmitt Trigger Control Register
#define P0_SM				*(volatile unsigned char *)(BASE_ADDR + 0x1204)
#define P0_SM_P0SM			P0_SM				// P0[7:0] port Schmitt trigger input enable

// P0 Port Interrupt Mask Register
#define P0_IMSK				*(volatile unsigned char *)(BASE_ADDR + 0x1205)
#define P0_IMSK_P0IE		P0_IMSK				// P0[7:0] port interrupt enable

// P0 Port Interrupt Edge Select Register
#define P0_EDGE				*(volatile unsigned char *)(BASE_ADDR + 0x1206)
#define P0_EDGE_P0EDGE		P0_EDGE				// P0[7:0] port interrupt edge select

// P0 Port Interrupt Flag Register
#define P0_IFLG				*(volatile unsigned char *)(BASE_ADDR + 0x1207)
#define P0_IFLG_P0IF		P0_IFLG				// P0[7:0] port interrupt flag

// P0 Port Chattering Filter Control Register
#define P0_CHAT				*(volatile unsigned char *)(BASE_ADDR + 0x1208)
#define BF_P0_CHAT			(*(volatile struct BbitF0_2And4_6 *)(BASE_ADDR + 0x1208))
#define P0_CHAT_P0CF2		BF_P0_CHAT.b4_b6	// P0[6:4] chattering filter time
#define P0_CHAT_P0CF1		BF_P0_CHAT.b0_b2	// P0[2:0] chattering filter time

// P0 Port Key-Entry Reset Configuration Register
#define P0_KRST				*(volatile unsigned char *)(BASE_ADDR + 0x1209)
#define BF_P0_KRST			(*(volatile struct BbitF0_1 *)(BASE_ADDR + 0x1209))
#define P0_KRST_P0KRST		BF_P0_KRST.b0_b1	// P0 port key-entry reset configuration

// P0 Port Input Data Register
#define P0_IEN				*(volatile unsigned char *)(BASE_ADDR + 0x120a)
#define P0_IEN_P0IEN		P0_IEN				// P0[7:0] port input enable

// P1 Port Input Data Register
#define P1_IN				*(volatile unsigned char *)(BASE_ADDR + 0x1210)
#define P1_IN_P1IN			P1_IN				// P1[7:0] port input data

// P1 Port Output Data Register
#define P1_OUT				*(volatile unsigned char *)(BASE_ADDR + 0x1211)
#define P1_OUT_P1OUT		P1_OUT				// P1[7:0] port output data

// P1 Port I/O Direction Control Register
#define P1_IO				*(volatile unsigned char *)(BASE_ADDR + 0x1212)
#define P1_IO_P1IO			P1_IO				// P1[7:0] port I/O direction select

// P1 Port Pull-up Control Register
#define P1_PU				*(volatile unsigned char *)(BASE_ADDR + 0x1213)
#define P1_PU_P1PU			P1_PU				// P1[7:0] port pull-up enable

// P1 Port Schmitt Trigger Control Register
#define P1_SM				*(volatile unsigned char *)(BASE_ADDR + 0x1214)
#define P1_SM_P1SM			P1_SM				// P1[7:0] port Schmitt trigger input enable

// P1 Port Interrupt Mask Register
#define P1_IMSK				*(volatile unsigned char *)(BASE_ADDR + 0x1215)
#define P1_IMSK_P1IE		P1_IMSK				// P1[7:0] port interrupt enable

// P1 Port Interrupt Edge Select Register
#define P1_EDGE				*(volatile unsigned char *)(BASE_ADDR + 0x1216)
#define P1_EDGE_P1EDGE		P1_EDGE				// P1[7:0] port interrupt edge select

// P1 Port Interrupt Flag Register
#define P1_IFLG				*(volatile unsigned char *)(BASE_ADDR + 0x1217)
#define P1_IFLG_P1IF		P1_IFLG				// P1[7:0] port interrupt flag

// P1 Port Chattering Filter Control Register
#define P1_CHAT				*(volatile unsigned char *)(BASE_ADDR + 0x1218)
#define BF_P1_CHAT			(*(volatile struct BbitF0_2And4_6 *)(BASE_ADDR + 0x1218))
#define P1_CHAT_P1CF2		BF_P1_CHAT.b4_b6	// P1[6:4] chattering filter time
#define P1_CHAT_P1CF1		BF_P1_CHAT.b0_b2	// P1[2:0] chattering filter time

// P1 Port Input Data Register
#define P1_IEN				*(volatile unsigned char *)(BASE_ADDR + 0x121a)
#define P1_IEN_P1IEN		P1_IEN				// P1[7:0] port input enable

// P2 Port Input Data Register
#define P2_IN				*(volatile unsigned char *)(BASE_ADDR + 0x1220)
#define P2_IN_P2IN			P2_IN				// P2[7:0] port input data

// P2 Port Output Data Register
#define P2_OUT				*(volatile unsigned char *)(BASE_ADDR + 0x1221)
#define P2_OUT_P2OUT		P2_OUT				// P2[7:0] port output data

// P2 Port I/O Direction Control Register
#define P2_IO				*(volatile unsigned char *)(BASE_ADDR + 0x1222)
#define P2_IO_P2IO			P2_IO				// P2[7:0] port I/O direction select

// P2 Port Pull-up Control Register
#define P2_PU				*(volatile unsigned char *)(BASE_ADDR + 0x1223)
#define P2_PU_P2PU			P2_PU				// P2[7:0] port pull-up enable

// P2 Port Schmitt Trigger Control Register
#define P2_SM				*(volatile unsigned char *)(BASE_ADDR + 0x1224)
#define P2_SM_P2SM			P2_SM				// P2[7:0] port Schmitt trigger input enable

// P2 Port Input Data Register
#define P2_IEN				*(volatile unsigned char *)(BASE_ADDR + 0x122a)
#define P2_IEN_P2IEN		P2_IEN				// P2[7:0] port input enable

// P3 Port Input Data Register
#define P3_IN				*(volatile unsigned char *)(BASE_ADDR + 0x1230)
#define BF_P3_IN			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1230))
#define P3_IN_P3IN			BF_P3_IN.b0_b3		// P3[3:0] port input data

// P3 Port Output Data Register
#define P3_OUT				*(volatile unsigned char *)(BASE_ADDR + 0x1231)
#define BF_P3_OUT			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1231))
#define P3_OUT_P3OUT		BF_P3_OUT.b0_b3		// P3[3:0] port output data

// P3 Port I/O Direction Control Register
#define P3_IO				*(volatile unsigned char *)(BASE_ADDR + 0x1232)
#define BF_P3_IO			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1232))
#define P3_IO_P3IO			BF_P3_IO.b0_b3		// P3[3:0] port I/O direction select

// P3 Port Pull-up Control Register
#define P3_PU				*(volatile unsigned char *)(BASE_ADDR + 0x1233)
#define BF_P3_PU			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1233))
#define P3_PU_P3PU			BF_P3_PU.b0_b3		// P3[3:0] port pull-up enable

// P3 Port Schmitt Trigger Control Register
#define P3_SM				*(volatile unsigned char *)(BASE_ADDR + 0x1234)
#define BF_P3_SM			(*(volatile struct BbitF0_3 *)(BASE_ADDR + 0x1234))
#define P3_SM_P3SM			BF_P3_SM.b0_b3		// P3[3:0] port Schmitt trigger input enable

// P3 Port Input Data Register
#define P3_IEN				*(volatile unsigned char *)(BASE_ADDR + 0x123a)
#define P3_IEN_P3IEN		P3_IEN				// P3[7:0] port input enable

// P0 Port Function Select Register
#define P0_PMUX				*(volatile unsigned char *)(BASE_ADDR + 0x12a0)
#define BF_P0_PMUX			(*(volatile struct BbitF *)(BASE_ADDR + 0x12a0))
#define P0_PMUX_P05MUX		BF_P0_PMUX.b5		// P05 port function select
#define P0_PMUX_P04MUX		BF_P0_PMUX.b4		// P04 port function select
#define P0_PMUX_P03MUX		BF_P0_PMUX.b3		// P03 port function select
#define P0_PMUX_P02MUX		BF_P0_PMUX.b2		// P02 port function select

// P1 Port Function Select Register
#define P1_PMUX				*(volatile unsigned char *)(BASE_ADDR + 0x12a1)
#define BF_P1_PMUX			(*(volatile struct BbitF *)(BASE_ADDR + 0x12a1))
#define P1_PMUX_P17MUX		BF_P1_PMUX.b7		// P17 port function select
#define P1_PMUX_P16MUX		BF_P1_PMUX.b6		// P16 port function select
#define P1_PMUX_P15MUX		BF_P1_PMUX.b5		// P15 port function select
#define P1_PMUX_P14MUX		BF_P1_PMUX.b4		// P14 port function select
#define P1_PMUX_P13MUX		BF_P1_PMUX.b3		// P13 port function select
#define P1_PMUX_P12MUX		BF_P1_PMUX.b2		// P12 port function select
#define P1_PMUX_P11MUX		BF_P1_PMUX.b1		// P11 port function select
#define P1_PMUX_P10MUX		BF_P1_PMUX.b0		// P10 port function select

// P2 Port Function Select Register
#define P2_PMUX				*(volatile unsigned char *)(BASE_ADDR + 0x12a2)
#define BF_P2_PMUX			(*(volatile struct BbitF *)(BASE_ADDR + 0x12a2))
#define P2_PMUX_P27MUX		BF_P2_PMUX.b7		// P27 port function select
#define P2_PMUX_P26MUX		BF_P2_PMUX.b6		// P26 port function select
#define P2_PMUX_P25MUX		BF_P2_PMUX.b5		// P25 port function select
#define P2_PMUX_P24MUX		BF_P2_PMUX.b4		// P24 port function select
#define P2_PMUX_P23MUX		BF_P2_PMUX.b3		// P23 port function select
#define P2_PMUX_P22MUX		BF_P2_PMUX.b2		// P22 port function select
#define P2_PMUX_P21MUX		BF_P2_PMUX.b1		// P21 port function select
#define P2_PMUX_P20MUX		BF_P2_PMUX.b0		// P20 port function select

// P3 Port Function Select Register
#define P3_PMUX				*(volatile unsigned char *)(BASE_ADDR + 0x12a3)
#define BF_P3_PMUX			(*(volatile struct BbitF *)(BASE_ADDR + 0x12a3))
#define P3_PMUX_P33MUX		BF_P3_PMUX.b3		// P33 port function select
#define P3_PMUX_P32MUX		BF_P3_PMUX.b2		// P32 port function select
#define P3_PMUX_P31MUX		BF_P3_PMUX.b1		// P31 port function select
#define P3_PMUX_P30MUX		BF_P3_PMUX.b0		// P30 port function select


/****************************************************
 ****** The Definition of PWM & Capture Timer Ch.0 **
 ****** [T16E]                                     **
 ****************************************************/
// PWM Timer Ch.0 Compare Data A Register
#define T16E_CA0			*(volatile unsigned short *)(BASE_ADDR + 0x1300)
#define T16E_CA0_T16ECA		T16E_CA0			// Compare data A

// PWM Timer Ch.0 Compare Data B Register
#define T16E_CB0			*(volatile unsigned short *)(BASE_ADDR + 0x1302)
#define T16E_CB0_T16ECB		T16E_CB0			// Compare data B

// PWM TImer Ch.0 Counter Data Register
#define T16E_TC0			*(volatile unsigned short *)(BASE_ADDR + 0x1304)
#define T16E_TC0_T16ETC		T16E_TC0			// Counter data

// PWM Timer Ch.0 Control Register
#define T16E_CTL0			*(volatile unsigned short *)(BASE_ADDR + 0x1306)
#define BF_T16E_CTL0		(*(volatile struct WbitF *)(BASE_ADDR + 0x1306))
#define T16E_CTL0_INITOL	BF_T16E_CTL0.b8		// Initial output level
#define T16E_CTL0_SELFM		BF_T16E_CTL0.b6		// Fine mode select
#define T16E_CTL0_CBUFEN	BF_T16E_CTL0.b5		// Comparison buffer enable
#define T16E_CTL0_INVOUT	BF_T16E_CTL0.b4		// Inverse output
#define T16E_CTL0_CLKSEL	BF_T16E_CTL0.b3		// Input clock select
#define T16E_CTL0_OUTEN		BF_T16E_CTL0.b2		// Clock output enable
#define T16E_CTL0_T16ERST	BF_T16E_CTL0.b1		// Timer reset
#define T16E_CTL0_T16ERUN	BF_T16E_CTL0.b0		// Timer run/stop control

// PWM Timer Ch.0 Input Clock Select Register
#define T16E_CLK0			*(volatile unsigned short *)(BASE_ADDR + 0x1308)
#define BF_T16E_CLK0		(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x1308))
#define T16E_CLK0_T16EDF	BF_T16E_CLK0.b0_b3	// Timer input clock select

// PWM Timer Ch.0 Interrupt Mask Register
#define T16E_INT0			*(volatile unsigned short *)(BASE_ADDR + 0x130a)
#define BF_T16E_INT0		(*(volatile struct WbitF *)(BASE_ADDR + 0x130a))
#define T16E_INT0_CBIE		BF_T16E_INT0.b1		// Compare B interrupt enable
#define T16E_INT0_CAIE		BF_T16E_INT0.b0		// Compare A interrupt enable

// PWM Timer Ch.0 Interrupt Mask flag Register
#define T16E_IFLG0			*(volatile unsigned short *)(BASE_ADDR + 0x130c)
#define BF_T16E_IFLG0		(*(volatile struct WbitF *)(BASE_ADDR + 0x130c))
#define T16E_IFLG0_CBIF		BF_T16E_IFLG0.b1		// Compare B interrupt flag
#define T16E_IFLG0_CAIF		BF_T16E_IFLG0.b0		// Compare A interrupt flag


/***********************************************
 ****** The Definition of MISC Registers *******
 ****** [MISC]                           *******
 ***********************************************/
// FLASHC Control Register
#define MISC_FL				*(volatile unsigned char *)(BASE_ADDR + 0x1320)
#define BF_MISC_FL			(*(volatile struct WbitF0_2And8_9 *)(BASE_ADDR + 0x1320))
#define MISC_FL_SRCYC		BF_MISC_FL.b8_b9		// SRAMC access cycle
#define MISC_FL_FLCYC		BF_MISC_FL.b0_b2		// FLASHC read access cycle

// OSC1 Peripheral Control Register
#define MISC_OSC1			*(volatile unsigned char *)(BASE_ADDR + 0x1322)
#define BF_MISC_OSC1		(*(volatile struct WbitF *)(BASE_ADDR + 0x1322))
#define MISC_OSC1_O1DBG		BF_MISC_OSC1.b0			// OSC1 peripheral control in debug mode

// MISC Protect register
#define MISC_PROT			*(volatile unsigned char *)(BASE_ADDR + 0x1324)
#define BF_MISC_PROT		(*(volatile struct WbitF0_15 *)(BASE_ADDR + 0x1324))
#define MISC_PROT_PROT		BF_MISC_PROT.b0_b15		// MISC register wirte protect

// IIRAM Size Select Register
#define MISC_IRAMSZ			*(volatile unsigned char *)(BASE_ADDR + 0x1326)
#define BF_MISC_IRAMSZ		(*(volatile struct WbitF0_1 *)(BASE_ADDR + 0x1326))
#define MISC_IRAMSZ_IRAMSZ	BF_MISC_IRAMSZ.b0_b1	// IRAM size select

// Vector Table Address Low Register
#define MISC_TTBRL			*(volatile unsigned char *)(BASE_ADDR + 0x1328)
#define BF_MISC_TTBRL		(*(volatile struct WbitF8_15 *)(BASE_ADDR + 0x1328))
#define MISC_TTBRL_TTBR		BF_MISC_TTBRL.b8_b15	// Vector table base address A[15:8]

// Vector Table Address High Register
#define MISC_TTBRH			*(volatile unsigned char *)(BASE_ADDR + 0x132a)
#define BF_MISC_TTBRH		(*(volatile struct WbitF0_7 *)(BASE_ADDR + 0x132a))
#define MISC_TTBRH_TTBR		BF_MISC_TTBRH.b0_b7		// Vector table base address A[23:16]

// PSR Register
#define MISC_PSR			*(volatile unsigned short *)(BASE_ADDR + 0x132c)
#define BF_MISC_PSR			(*(volatile struct WbitF5_7 *)(BASE_ADDR + 0x132c))
#define MISC_PSR_PSRIL		BF_MISC_PSR.b5_b7		// PSR interrupt level(IL) bits
#define MISC_PSR_PSRIE		BF_MISC_PSR.b4			// PSR interrupt enable(IE) bits
#define MISC_PSR_PSRC		BF_MISC_PSR.b3			// PSR carry(C) flag
#define MISC_PSR_PSRV		BF_MISC_PSR.b2			// PSR overflow(V) flag
#define MISC_PSR_PSRZ		BF_MISC_PSR.b1			// PSR zero(Z) flag
#define MISC_PSR_PSRN		BF_MISC_PSR.b0			// PSR nagative(N) flag


/***********************************************
 ****** The Definition of Remoto Controller ****
 ****** [REMC]                              ****
 ***********************************************/
// REMC Configuration Register
#define REMC_CFG			*(volatile unsigned short *)(BASE_ADDR + 0x1340)
#define BF_REMC_CFG			(*(volatile struct WbitF8_11AND12_15 *)(BASE_ADDR + 0x1340))
#define REMC_CFG_CGCLK		BF_REMC_CFG.b12_b15		// Carrier output clock
#define REMC_CFG_LCCLK		BF_REMC_CFG.b8_b11		// Length counter clock select
#define REMC_CFG_REMMD		BF_REMC_CFG.b1			// REMC mode select
#define REMC_CFG_REMEN		BF_REMC_CFG.b0			// REMC enable

// REMC Carrier Length Setup Register
#define REMC_CAR			*(volatile unsigned short *)(BASE_ADDR + 0x1342)
#define BF_REMC_CAR			(*(volatile struct WbitF0_5And8_13 *)(BASE_ADDR + 0x1342))
#define REMC_CAR_REMCL		BF_REMC_CAR.b8_b13		// L carrier length setup
#define REMC_CAR_REMCH		BF_REMC_CAR.b0_b5		// H carrier length setup

// REMC Length Counter Register
#define REMC_LCNT			*(volatile unsigned short *)(BASE_ADDR + 0x1344)
#define BF_REMC_LCNT		(*(volatile struct WbitF8_15 *)(BASE_ADDR + 0x1344))
#define REMC_LCNT_REMLEN	BF_REMC_LCNT.b8_b15		// Transmit/receive data length count
#define REMC_LCNT_REMDT		BF_REMC_LCNT.b0			// Transmit/receive data

// REMC Interrupt Mask Register
#define REMC_INT			*(volatile unsigned short *)(BASE_ADDR + 0x1346)
#define BF_REMC_INT			(*(volatile struct WbitF *)(BASE_ADDR + 0x1346))
#define REMC_INT_REMFIF		BF_REMC_INT.b10			// Falling edge interrupt flag 
#define REMC_INT_REMRIF		BF_REMC_INT.b9			// Rising edge interrupt flag 
#define REMC_INT_REMUIF		BF_REMC_INT.b8			// Underflow interrupt flag 
#define REMC_INT_REMFIE		BF_REMC_INT.b2			// Falling edge interrupt enable
#define REMC_INT_REMRIE		BF_REMC_INT.b1			// Rising edge interrupt enable
#define REMC_INT_REMUIE		BF_REMC_INT.b0			// Underflow interrupt enable


/****************************************************
 ****** The Definition of PWM & Capture Timer Ch.1 **
 ****** [T16E]                                     **
 ****************************************************/
// PWM Timer Ch.1 Compare Data A Register
#define T16E_CA1			*(volatile unsigned short *)(BASE_ADDR + 0x1360)
#define T16E_CA1_T16ECA		T16E_CA1			// Compare data A

// PWM Timer Ch.1 Compare Data B Register
#define T16E_CB1			*(volatile unsigned short *)(BASE_ADDR + 0x1362)
#define T16E_CB1_T16ECB		T16E_CB1			// Compare data B

// PWM TImer Ch.1 Counter Data Register
#define T16E_TC1			*(volatile unsigned short *)(BASE_ADDR + 0x1364)
#define T16E_TC1_T16ETC		T16E_TC1			// Counter data

// PWM Timer Ch.1 Control Register
#define T16E_CTL1			*(volatile unsigned short *)(BASE_ADDR + 0x1366)
#define BF_T16E_CTL1		(*(volatile struct WbitF *)(BASE_ADDR + 0x1366))
#define T16E_CTL1_INITOL	BF_T16E_CTL1.b8		// Initial output level
#define T16E_CTL1_SELFM		BF_T16E_CTL1.b6		// Fine mode select
#define T16E_CTL1_CBUFEN	BF_T16E_CTL1.b5		// Comparison buffer enable
#define T16E_CTL1_INVOUT	BF_T16E_CTL1.b4		// Inverse output
#define T16E_CTL1_CLKSEL	BF_T16E_CTL1.b3		// Input clock select
#define T16E_CTL1_OUTEN		BF_T16E_CTL1.b2		// Clock output enable
#define T16E_CTL1_T16ERST	BF_T16E_CTL1.b1		// Timer reset
#define T16E_CTL1_T16ERUN	BF_T16E_CTL1.b0		// Timer run/stop control

// PWM Timer Ch.1 Input Clock Select Register
#define T16E_CLK1			*(volatile unsigned short *)(BASE_ADDR + 0x1368)
#define BF_T16E_CLK1		(*(volatile struct WbitF0_3 *)(BASE_ADDR + 0x1368))
#define T16E_CLK1_T16EDF	BF_T16E_CLK1.b0_b3	// Timer input clock select

// PWM Timer Ch.1 Interrupt Mask Register
#define T16E_INT1			*(volatile unsigned short *)(BASE_ADDR + 0x136a)
#define BF_T16E_INT1		(*(volatile struct WbitF *)(BASE_ADDR + 0x136a))
#define T16E_INT1_CBIE		BF_T16E_INT1.b9		// Compare B interrupt enable
#define T16E_INT1_CAIE		BF_T16E_INT1.b8		// Compare A interrupt enable

// PWM Timer Ch.1 Interrupt Mask flag Register
#define T16E_IFLG1			*(volatile unsigned short *)(BASE_ADDR + 0x136c)
#define BF_T16E_IFLG1		(*(volatile struct WbitF *)(BASE_ADDR + 0x136c))
#define T16E_IFLG1_CBIF		BF_T16E_IFLG1.b1		// Compare B interrupt flag
#define T16E_IFLG1_CAIF		BF_T16E_IFLG1.b0		// Compare A interrupt flag



#endif /*S1C17702_H_*/
