/*************************************************************
lcdManager.c

This is Lcd Manager program.
Main process of this program is
change charactor to font, and show font to LCD pannel.

history : 2008/04/07	start
functions added by TK : 2010/03/17
************************************************************/

/* #include */
#include <string.h>
#include "lcdFont.h"
#include "lcdManager.h"

/* Prototype */
static const unsigned char *selectLcdFont(unsigned char);

/* global */
// LCD Display memory of each line
static const unsigned long displayMemory[4] = {
	0x80000, 0x80100, 0x80200, 0x80300
};


// LCD Checker pattern bit
static const unsigned char checkerLine[DISPLAY_ROW_SIZE] = {
	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,
	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,
	0xaa, 0x55,	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,
	0xaa, 0x55, 0xaa, 0x55,	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,
	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,
	0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55,	0xaa, 0x55, 0xaa, 0x55
};

// LCD Checker pattern bit
static const unsigned char checkerLine2[DISPLAY_ROW_SIZE] = {
	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,
	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,
	0xa0, 0x05,	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,
	0xa0, 0x05, 0xa0, 0x05,	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,
	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,
	0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05, 0xa0, 0x05,	0xa0, 0x05, 0xa0, 0x05
};


// LCD RAM max (SEG)
#define MAX_SEG_SIZE (unsigned char) 96

/*************************************************************
 * SelectLcdFont function.
 * This function select a Lcd Font.
 *
 * param: unsgined char  ch  Select key.
 * return: char *  Pointer of Lcd Font in lcdFontArray.
 * history: 2008/04/07	start
 ************************************************************/
static const unsigned char * selectLcdFont(unsigned char ch) {
	if((FIRST_NO_OF_ASCII_CODE <= ch) && (ch <= END_NO_OF_ASCII_CODE)) {
		return lcdFontArray[ch - FIRST_NO_OF_ASCII_CODE];
	} else {
		return lcdFontArray[0];
	}
}



/*************************************************************
 * ClearLcdLine function.
 * This function clear a specified Lcd line.
 *
 * param: char  lineNo  Lcd line No. which you want to clear. (0 - 3)
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void clearLcdLine(unsigned char lineNo) {
	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}
	memset((unsigned char *)displayMemory[lineNo], 0x00, MAX_SEG_SIZE);
}

/*************************************************************
 * ClearLcdLine function.
 * This function clear a specified Lcd line.
 *
 * param: char  lineNo  Lcd line No. which you want to clear. (0 - 3)
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void fillLcdLine(unsigned char lineNo) {
	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}
	memset((unsigned char *)displayMemory[lineNo], 0xff, MAX_SEG_SIZE);
}
/*************************************************************
 * clearAllLcdLine function.
 * This program clear all lcd line(Line0 - 3).
 *
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void fillAllLcdLine(void) {
	fillLcdLine(0);
	fillLcdLine(1);
	fillLcdLine(2);
	fillLcdLine(3);
}
/*************************************************************
 * clearAllLcdLine function.
 * This program clear all lcd line(Line0 - 3).
 *
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void clearAllLcdLine(void) {
	clearLcdLine(0);
	clearLcdLine(1);
	clearLcdLine(2);
	clearLcdLine(3);
}
/*************************************************************
 * displayChecker function.
 * This function displays checker line.
 *
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void displayChecker(void) {
	memcpy((unsigned char *)displayMemory[0], checkerLine, DISPLAY_ROW_SIZE);
	memcpy((unsigned char *)displayMemory[1], checkerLine, DISPLAY_ROW_SIZE);
	memcpy((unsigned char *)displayMemory[2], checkerLine, DISPLAY_ROW_SIZE);
	memcpy((unsigned char *)displayMemory[3], checkerLine, DISPLAY_ROW_SIZE);
}

/*************************************************************
 * displayChecker function.
 * This function displays checker line.
 *
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void displayChecker2(void) {
	memcpy((unsigned char *)displayMemory[0], checkerLine2, DISPLAY_ROW_SIZE);
	memcpy((unsigned char *)displayMemory[1], checkerLine2, DISPLAY_ROW_SIZE);
	memcpy((unsigned char *)displayMemory[2], checkerLine2, DISPLAY_ROW_SIZE);
	memcpy((unsigned char *)displayMemory[3], checkerLine2, DISPLAY_ROW_SIZE);
}

/*************************************************************
 * displayChar function.
 * This function displays 1 Charactor
 * at specified Lcd line and specified charactor row.
 *
 * param: unsigned char  lineNo  Lcd line No. which you want to display. (0 - 3)
 * param: unsigned char  charNo  Lcd Charactor row No. which you want to display. (0 - 15)
 * param: unsgined char   ch      Display charactors.
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void displayChar(unsigned char lineNo, unsigned char charNo, unsigned char ch) {
	unsigned long displayStartAdd;
	if ((3 < lineNo) || (15 < charNo)) {
		// it is over flow, so return.
		return;
	}
	displayStartAdd = displayMemory[lineNo] + (DISPLAY_CH_ROW_SIZE * charNo);
	memcpy((unsigned char *)displayStartAdd, selectLcdFont(ch), DISPLAY_CH_ROW_SIZE);
}

/*************************************************************
 * DisplayStr function.
 * This function displays String(0 - 15 charactors)
 * at specified Lcd line.
 *
 * param: unsigned char  lineNo  Lcd line No. which you want to display. (0 - 3)
 * param: unsinged char*  str     Display String(0-16 charactors).
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void displayStr(unsigned char lineNo, unsigned char *str) {
	unsigned long  i; 		// loop counter
	unsigned long displayStartAdd;

	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}

	for(i = 0; i < 16; i++) {
		if(*(str + i) == '\0') {
			break;	// end of String.
		}
		displayStartAdd = displayMemory[lineNo] + (DISPLAY_CH_ROW_SIZE * i);
		memcpy((unsigned char *)displayStartAdd, selectLcdFont(*(str + i)), DISPLAY_CH_ROW_SIZE);
	}
}

/*************************************************************
 * DisplayScreen function.
 * This function displays virtual screen (12x4) to
 * LCD bitmap screen (72 x 32)
 *
 * param: unsinged char*  str   virtual screen address (12x4).
 * return: void
 * history: 2010/03/17	start by TK
 ************************************************************/
void displayScreen(unsigned char *str) {

	unsigned long  i,j,k; 		// loop counter
	unsigned long displayStartAdd;

	k = 0;
	for(i = 0; i < 4; i++) {
		displayStartAdd = displayMemory[i];
		for (j = 0 ; j<12 ; j++) {
			memcpy((unsigned char *)displayStartAdd, selectLcdFont(*(str + k)), DISPLAY_CH_ROW_SIZE);
			displayStartAdd += DISPLAY_CH_ROW_SIZE;
			k ++ ;
		}
	}
}


/*************************************************************
 * DisplayData function.
 * This function displays something at specified Lcd line.
 *
 * param: unsigned char  lineNo     Lcd line No. which you want to display. (0 - 3)
 * param: unsinged char*  data       Start pointer of display-data.
 * param: unsinged char  byte       Bytes of display-data (0 - 96).
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void displayData(unsigned char lineNo, unsigned char * data, unsigned char byte) {
	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}
	if(MAX_SEG_SIZE < byte) {
		byte = MAX_SEG_SIZE;	// max ram size at 1 line is 96.
	}

	memcpy((unsigned char *)displayMemory[lineNo], data, byte);
}


/*************************************************************
 * reverseLcdLine function.
 * This function reverse monochrome at specified Lcd line
 * and specified charactor row.
 *
 * param: unsigned char  lineNo  Lcd line No. which you want to display. (0 - 3)
 * param: unsigned char  charNo  Lcd Charactor row No. which you want to display. (0 - 15)
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void reverseChar(unsigned char lineNo, unsigned char charNo) {
	unsigned long  i; 		// loop counter
	unsigned long startAdd;	// start ram address of the specified Lcd line.

	if ((3 < lineNo) || (15 < charNo)) {
		// it is over flow, so return.
		return;
	}

	startAdd = displayMemory[lineNo] + (charNo * DISPLAY_CH_ROW_SIZE);
	for(i = 0; i < DISPLAY_CH_ROW_SIZE; i++) {
		// reverses bit
		*(volatile unsigned char *)(startAdd + i) = ~(*(volatile unsigned char *)(startAdd + i));
	}
}


/*************************************************************
 * reverseLcdLine function.
 * This function reverse monochrome at specified Lcd line.
 *
 * param: unsgined char  lineNo  Lcd line No. which you want to display. (0 - 3)
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void reverseStr(unsigned char lineNo) {
	unsigned long i; 		// loop counter
	unsigned long startAdd;	// start ram address of the specified Lcd line.

	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}

	startAdd = displayMemory[lineNo];
	for(i = 0; i < MAX_SEG_SIZE; i++) {
		// reverses bit
		*(volatile unsigned char *)(startAdd + i) = ~(*(volatile unsigned char *)(startAdd + i));
	}
}

/*************************************************************
 * LineScrollLeft function.
 * This function scrolls line to left.
 *
 * param: unsgined char  lineNo    Lcd line No. which you want to scroll. (0 - 3)
 * param: unsgined char  turnPoint scroll area. In 0 to this value area scrolls.(0 - 95)
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void lineScrollLeft(unsigned char lineNo, unsigned char turnPoint) {
	unsigned char tmp;		// first byte copy
	unsigned long adrress;	// working adrress of display memory

	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}

	if(MAX_SEG_SIZE <= turnPoint) {
		turnPoint = MAX_SEG_SIZE - 1;	// max ram size at 1 line is 95.
	}

	adrress = displayMemory[lineNo];

	// copy first byte
	tmp = *(volatile unsigned char *)adrress;

	for( ; adrress < displayMemory[lineNo] + turnPoint; adrress++) {
		// 1byte left scroll
		*(volatile unsigned char *)adrress = *(volatile unsigned char *)(adrress + 1);
	}

	// copy first byte to end byte
	*(volatile unsigned char *)adrress = tmp;
}


/*************************************************************
 * LineScrollLeft function.
 * This function scrolls line to right.
 *
 * param: unsgined char  lineNo    Lcd line No. which you want to scroll. (0 - 3)
 * param: unsgined char  turnPoint scroll area. In 0 to this value area scrolls.(0 - 95)
 * return: void
 * history: 2008/04/07	start
 ************************************************************/
void lineScrollRight(unsigned char lineNo, unsigned char turnPoint) {
	unsigned char tmp;		// first byte copy
	unsigned long adrress;	// working adrress of display memory

	if(3 < lineNo) {
		// it is over flow, so return.
		return;
	}

	if(MAX_SEG_SIZE <= turnPoint) {
		turnPoint = MAX_SEG_SIZE - 1;	// max ram size at 1 line is 95.
	}

	adrress = displayMemory[lineNo] + turnPoint;

	// copy first byte
	tmp = *(volatile unsigned char *)adrress;

	for( ; adrress > displayMemory[lineNo]; adrress--) {
		// 1byte left scroll
		*(volatile unsigned char *)adrress = *(volatile unsigned char *)(adrress - 1);
	}

	// copy first byte to end byte
	*(volatile unsigned char *)adrress = tmp;
}

/************************************************************************
 *   Clear work screen with 16bit mode
 *   param    :     void
 *   return   :     none
 *   history  :     2010/03/26	start
 ***********************************************************************/
void clearTempScreen(unsigned char *temp_screen){								//**TK**
	unsigned int *temp;
	unsigned int i;
	temp = (unsigned int *)temp_screen;
	for (i = 0 ; i <(200); i++){
		*temp = 0x0000;
		temp ++;
	}
}

/*************************************************************
 * DisplayScreen function.
 * This function displays virtual screen (12x4) to
 * LCD bitmap screen (72 x 32)
 *
 * param: unsinged char*  str   virtual screen address (12x4).
 * return: void
 * history: 2010/03/17	start by TK
 ************************************************************/
void displayTempScreen(unsigned char *temp_screen) {

	unsigned int  i; 		// loop counter
	unsigned long displayStartAdd;

	for(i = 0; i < 4; i++) {
		displayStartAdd = displayMemory[i];
		memcpy((unsigned char *)displayStartAdd,(unsigned char *)(temp_screen) + 80 * i,72);
	}
}

/************************************************************************
 *   Put character to tempscreen
 *   param    :     x,y,ch code
 *   return   :     none
 *   history  :     2010/03/26	start
 ***********************************************************************/
void putChar(unsigned char *temp_screen,unsigned int x, unsigned int y, unsigned char ch){	//**TK**
	unsigned int y0,y1,i;
	unsigned int ch0;
	unsigned char *p0,*p1,*p2;

	y0 = y/8; y1 = y % 8;
	p0 =(unsigned char *)lcdFontArray + ch*6;
	p1 = (unsigned char *)temp_screen + y0 * 80 + x;
	p2 = p1 + 80;
	for (i = 0 ; i<6 ; i++){
		ch0 = ((unsigned int)(*p0) ) << y1;
		*p1 |= ch0 & 0xff;
		*p2 |= ch0 >> 8;
		p0++; p1++; p2++;
	}
}
